.. py:currentmodule:: rubin_scheduler.utils

.. _utils:

=====================
rubin_scheduler utils
=====================

The `rubin_scheduler.utils` module provides basic utilities that are useful throughout rubin_scheduler and rubin_sim.
These include utilities for tree generation in healpy and other healpix manipulation,
coordinate transform utilities, as well as other useful tools.
